@@ -23,6 +23,7 @@ import json, pickle
 from . import coredata, build
 import argparse
 import sys, os
+import pathlib
 
 parser = argparse.ArgumentParser()
 parser.add_argument('--targets', action='store_true', dest='list_targets', default=False,
@@ -56,23 +57,29 @@ def determine_installed_path(target, installdata):
     fname = i[0]
     outdir = i[1]
     outname = os.path.join(installdata.prefix, outdir, os.path.split(fname)[-1])
-    return outname
+    # Normalize the path by using os.path.sep consistently, etc.
+    # Does not change the effective path.
+    return str(pathlib.PurePath(outname))
 
 
 def list_installed(installdata):
     res = {}
     if installdata is not None:
+        for path, installdir, aliases, unknown1, unknown2 in installdata.targets:
+            res[os.path.join(installdata.build_dir, path)] = os.path.join(installdata.prefix, installdir, os.path.basename(path))
         for path, installpath, unused_prefix in installdata.data:
             res[path] = os.path.join(installdata.prefix, installpath)
+        for path, installdir in installdata.headers:
+            res[path] = os.path.join(installdata.prefix, installdir, os.path.basename(path))
+        for path, installpath in installdata.man:
+            res[path] = os.path.join(installdata.prefix, installpath)
     print(json.dumps(res))
 
 
 def list_targets(coredata, builddata, installdata):
     tlist = []
     for (idname, target) in builddata.get_targets().items():
-        t = {}
-        t['name'] = target.get_basename()
-        t['id'] = idname
+        t = {'name': target.get_basename(), 'id': idname}
         fname = target.get_filename()
         if isinstance(fname, list):
             fname = [os.path.join(target.subdir, x) for x in fname]
@@ -111,23 +118,11 @@ def list_target_files(target_name, coredata, builddata):
     print(json.dumps(sources))
 
 def list_buildoptions(coredata, builddata):
-    buildtype = {'choices': ['plain', 'debug', 'debugoptimized', 'release', 'minsize'],
-                 'type': 'combo',
-                 'value': coredata.get_builtin_option('buildtype'),
-                 'description': 'Build type',
-                 'name': 'type'}
-    strip = {'value': coredata.get_builtin_option('strip'),
-             'type': 'boolean',
-             'description': 'Strip on install',
-             'name': 'strip'}
-    unity = {'value': coredata.get_builtin_option('unity'),
-             'type': 'boolean',
-             'description': 'Unity build',
-             'name': 'unity'}
-    optlist = [buildtype, strip, unity]
+    optlist = []
     add_keys(optlist, coredata.user_options)
     add_keys(optlist, coredata.compiler_options)
     add_keys(optlist, coredata.base_options)
+    add_keys(optlist, coredata.builtins)
     print(json.dumps(optlist))
 
 def add_keys(optlist, options):
@@ -135,9 +130,7 @@ def add_keys(optlist, options):
     keys.sort()
     for key in keys:
         opt = options[key]
-        optdict = {}
-        optdict['name'] = key
-        optdict['value'] = opt.value
+        optdict = {'name': key, 'value': opt.value}
         if isinstance(opt, coredata.UserStringOption):
             typestr = 'string'
         elif isinstance(opt, coredata.UserBooleanOption):
@@ -164,12 +157,12 @@ def list_buildsystem_files(coredata, builddata):
     print(json.dumps(filelist))
 
 def list_deps(coredata):
-    result = {}
+    result = []
     for d in coredata.deps.values():
         if d.found():
             args = {'compile_args': d.get_compile_args(),
                     'link_args': d.get_link_args()}
-            result[d.name] = args
+            result += [d.name, args]
     print(json.dumps(result))
 
 def list_tests(testdata):
@@ -193,9 +186,7 @@ def list_tests(testdata):
     print(json.dumps(result))
 
 def list_projinfo(builddata):
-    result = {}
-    result['name'] = builddata.project_name
-    result['version'] = builddata.project_version
+    result = {'name': builddata.project_name, 'version': builddata.project_version}
     subprojects = []
     for k, v in builddata.subprojects.items():
         c = {'name': k,
